'use client';

import React, { useState } from 'react';
import TailwindDropdown from '../universal/TailwindDropdown';

const locations = {
    title: "Select Your City",
    image: "/icons/location.png",
    data: ["Mumbai", "Pune", "Chennai", "Delhi", "Noida"]
};

const propertyType = {
    title: "Choose Property Type",
    image: "icons/down-arrow.png",
    data: ["Property 1", "Property 2", "Property 3"]
};

const priceRange = {
    title: "Choose Price Range",
    data: ["100K - 1000K", "200K - 2000K", "300K - 3000K"]
};

const BuySell = () => {
    const [option, setOption] = useState("buy");

    return (
        <div className="w-full max-w-6xl mx-auto">
            {/* Buy/Sell Toggle Buttons */}
            <div className="flex flex-wrap sm:flex-nowrap gap-0">
                <button
                    className={`flex-1 sm:flex-none font-semibold py-2 px-4 sm:px-8 transition-colors rounded-tl-lg ${
                        option === "buy"
                            ? "bg-secondary text-white"
                            : "bg-white text-gray-800 hover:bg-gray-50"
                    }`}
                    onClick={() => setOption("buy")}
                >
                    BUY
                </button>
                <button
                    className={`flex-1 sm:flex-none font-semibold py-2 px-4 sm:px-8 transition-colors rounded-tr-lg ${
                        option === "sell"
                            ? "bg-secondary text-white"
                            : "bg-white text-gray-800 hover:bg-gray-50"
                    }`}
                    onClick={() => setOption("sell")}
                >
                    SELL
                </button>
            </div>

            {/* Search Filters Container */}
            <div className="bg-white rounded-tr-lg rounded-bl-lg rounded-br-lg p-4 sm:p-6">
                <div className="flex flex-col lg:flex-row gap-6 lg:gap-8">
                    {/* Filters Section */}
                    <div className="flex flex-col sm:flex-row gap-6 flex-1">
                        {/* Location Filter */}
                        <div className="flex-1 sm:border-r border-tertiary sm:pr-6">
                            <p className="font-semibold mb-2">Location</p>
                            <TailwindDropdown
                                title={locations.title}
                                image={locations.image}
                                data={locations.data}
                            />
                        </div>

                        {/* Property Type Filter */}
                        <div className="flex-1 sm:border-r border-tertiary sm:pr-6">
                            <p className="font-semibold mb-2">Property Type</p>
                            <TailwindDropdown
                                title={propertyType.title}
                                image={propertyType.image}
                                data={propertyType.data}
                            />
                        </div>

                        {/* Price Range Filter */}
                        <div className="flex-1">
                            <p className="font-semibold mb-2">Price Range</p>
                            <TailwindDropdown
                                title={priceRange.title}
                                data={priceRange.data}
                            />
                        </div>
                    </div>

                    {/* Search Button Section */}
                    <div className="flex items-center justify-center lg:border-l border-tertiary lg:pl-8">
                        <img
                            src="/search-button.png"
                            alt="Search"
                            className="w-12 h-12 cursor-pointer hidden lg:block"
                        />
                        <button className="w-full lg:hidden bg-brand text-white font-semibold py-3 px-6 rounded-lg hover:bg-opacity-90 transition-colors">
                            Search
                        </button>
                    </div>
                </div>
            </div>
        </div>
    );
};

export default BuySell;